@@ -8,6 +8,8 @@ from .memory import memory_collector
 from .blkio import blkio_collector
 from .cpu import cpu_collector
 from .unified import unified_collector
+from .cpuset import cpuset_collector
+from .pids import pids_collector
 
 log = logging.getLogger(__name__)
 
@@ -17,6 +19,8 @@ HANDLER_REGISTRY = MappingProxyType(
         "blkio": blkio_collector,
         "cpu,cpuacct": cpu_collector,
         "unified": unified_collector,
+        "cpuset": cpuset_collector,
+        "pids": pids_collector,
     }
 )
 
